#include <SDL.h>
#include <SDL_image.h>

#include <godlibdefines.h>
#include <gp2x.h>
#include <sdltools.h>
#include <sdlttf.h>

using namespace std;

SDL_Surface *screen = NULL;
SDL_Joystick *joy = NULL;

void Terminate(void) {
	SDL_Quit();
#ifdef GP2X
	chdir("/usr/gp2x");
	execl("/usr/gp2x/gp2xmenu", "/usr/gp2x/gp2xmenu", NULL);
#endif
}

int main (int argc, char **argv) {
	int done;

	if (SDL_Init (SDL_INIT_VIDEO | SDL_INIT_AUDIO | SDL_INIT_JOYSTICK) < 0) {
		fprintf (stderr, "Couldn't initialize SDL: %s\n", SDL_GetError ());
		exit (1);
	}
	atexit (Terminate);

	SDL_ShowCursor(SDL_DISABLE);

	screen = SDL_SetVideoMode (SCREEN_WIDTH, SCREEN_HEIGHT, 16, SDL_SWSURFACE);
	if (screen == NULL) {
		fprintf (stderr, "Couldn't set 320x240x16 video mode: %s\n", SDL_GetError ());
		exit (2);
	}

	if (SDL_NumJoysticks() > 0) {
		joy = SDL_JoystickOpen(0);
		if(!joy) {
			fprintf (stderr, "Couldn't open joystick 0: %s\n", SDL_GetError ());
		}
	}

	if (TTF_Init() == -1) {
		exit(3);
	}

#ifdef LINUX
#endif

#ifdef GP2X
#endif
	SDLTTF *ttf=new SDLTTF(FONT,12);
	ttf->setForegroundColor(255,255,0);

	SDL_Event event;

	while (!done) {
		while (SDL_PollEvent (&event)) {
			switch (event.type) {
				case SDL_KEYDOWN:
				case SDL_JOYBUTTONDOWN:
					if (
							( (event.key.keysym.sym == SDLK_c) && (event.key.keysym.mod & (KMOD_LCTRL | KMOD_RCTRL)) ) ||
							( event.jbutton.button == VK_SELECT )
					   ) {
						done = 1;
					}
					if (
							(event.key.keysym.sym==SDLK_RETURN) ||
							(event.jbutton.button == VK_START)
					   ) {
					}
					break;
				case SDL_KEYUP:
					break;
				case SDL_JOYBUTTONUP:
					break;
				case SDL_QUIT:
					done = 1;
					break;
				default:
					break;
			}
		}

		sdlLock(screen);
		sdlUnlock(screen);
		SDL_Flip(screen);
	}

	return 0;
}
